@@ -8,51 +8,10 @@ use warnings;
 use HTML::TreeBuilder::XPath;
 use Scalar::Util (qw(blessed));
 
-=head1 NAME
 
-MediaWiki::CleanupHTML - cleanup the MediaWiki-generated HTML from MediaWiki
-embellishments.
-
-=head1 VERSION
-
-Version 0.0.2
-
-=cut
-
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 
-=head1 SYNOPSIS
-
-    use MediaWiki::CleanupHTML;
-
-    open my $fh, '<:encoding(UTF-8)', $filename
-        or die "Cannot open '$filename' - $!";
-
-    my $cleaner = MediaWiki::CleanupHTML->new({ fh => $fh });
-
-    open my $out_fh, '>:encoding(UTF-8)', $processed_filename
-        or die "Cannot open '$processed_filename' for output - $!";
-
-    $cleaner->print_into_fh($out_fh);
-
-    $cleaner->destroy_resources();
-
-=head1 DESCRIPTION
-
-The HTML rendered on MediaWiki pages is full of MediaWiki-specific
-embellishments such as edit sections. This module attempts to clean it up
-and return a more straightforward HTML. Note that the HTML returned by
-MediaWiki APIs may not always available (for instance if the wiki is down), so
-this module should be considered a fallback.
-
-=head1 SUBROUTINES/METHODS
-
-=head2 MediaWiki::CleanupHTML->new({fh => $fh})
-
-The constructor - accepts the filehandle from which to read the XHTML.
-
-=cut
 
 sub new
 {
@@ -183,11 +142,6 @@ sub _process
     return;
 }
 
-=head2 $cleaner->print_into_fh($fh)
-
-Output to a filehandle. The filehandle should be able to process UTF-8 output.
-
-=cut
 
 sub print_into_fh
 {
@@ -198,12 +152,6 @@ sub print_into_fh
     print {$fh} $self->_tree->as_XML();
 }
 
-=head2 $cleaner->destroy_resources()
-
-Destroy the allocated resources (of the L<HTML::TreeBuilder> tree, etc.). Must
-be called before destruction.
-
-=cut
 
 sub destroy_resources
 {
@@ -224,6 +172,67 @@ sub DESTROY
     return;
 }
 
+
+1; # End of MediaWiki::CleanupHTML
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+MediaWiki::CleanupHTML - cleanup the MediaWiki-generated HTML from MediaWiki
+embellishments.
+
+=head1 VERSION
+
+version 0.0.3
+
+=head1 SYNOPSIS
+
+    use MediaWiki::CleanupHTML;
+
+    open my $fh, '<:encoding(UTF-8)', $filename
+        or die "Cannot open '$filename' - $!";
+
+    my $cleaner = MediaWiki::CleanupHTML->new({ fh => $fh });
+
+    open my $out_fh, '>:encoding(UTF-8)', $processed_filename
+        or die "Cannot open '$processed_filename' for output - $!";
+
+    $cleaner->print_into_fh($out_fh);
+
+    $cleaner->destroy_resources();
+
+=head1 DESCRIPTION
+
+The HTML rendered on MediaWiki pages is full of MediaWiki-specific
+embellishments such as edit sections. This module attempts to clean it up
+and return a more straightforward HTML. Note that the HTML returned by
+MediaWiki APIs may not always available (for instance if the wiki is down), so
+this module should be considered a fallback.
+
+=head1 VERSION
+
+Version 0.0.3
+
+=head1 SUBROUTINES/METHODS
+
+=head2 MediaWiki::CleanupHTML->new({fh => $fh})
+
+The constructor - accepts the filehandle from which to read the XHTML.
+
+=head2 $cleaner->print_into_fh($fh)
+
+Output to a filehandle. The filehandle should be able to process UTF-8 output.
+
+=head2 $cleaner->destroy_resources()
+
+Destroy the allocated resources (of the L<HTML::TreeBuilder> tree, etc.). Must
+be called before destruction.
+
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/> .
@@ -240,11 +249,14 @@ You can find documentation for this module with the perldoc command.
 
     perldoc MediaWiki::CleanupHTML
 
-
 You can also look for information at:
 
 =over 4
 
+=item * MetaCPAN
+
+L<http://metacpan.org/release/MediaWiki-CleanupHTML>
+
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=MediaWiki-CleanupHTML>
@@ -257,10 +269,6 @@ L<http://annocpan.org/dist/MediaWiki-CleanupHTML>
 
 L<http://cpanratings.perl.org/d/MediaWiki-CleanupHTML>
 
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/MediaWiki-CleanupHTML/>
-
 =back
 
 =head1 ACKNOWLEDGEMENTS
@@ -296,7 +304,141 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=MediaWiki-CleanupHTML or by email
+to bug-mediawiki-cleanuphtml@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc MediaWiki::CleanupHTML
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/MediaWiki-CleanupHTML>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/MediaWiki-CleanupHTML>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=MediaWiki-CleanupHTML>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/MediaWiki-CleanupHTML>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/MediaWiki-CleanupHTML>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/MediaWiki-CleanupHTML>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/MediaWiki-CleanupHTML>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/M/MediaWiki-CleanupHTML>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=MediaWiki-CleanupHTML>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=MediaWiki::CleanupHTML>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-mediawiki-cleanuphtml at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MediaWiki-CleanupHTML>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<http://bitbucket.org/shlomif/perl-mediawiki-cleanuphtml>
+
+  hg clone ssh://hg@bitbucket.org/shlomif/perl-mediawiki-cleanuphtml
 
 =cut
-
-1; # End of MediaWiki::CleanupHTML
